Type: Package
Package: dabestr
Title: Data Analysis using Bootstrap-Coupled Estimation
Version: 2025.3.15
Maintainer: Yishan Mai <maiyishan@u.duke.nus.edu>
Authors@R: c(
    person("Joses W.", "Ho", , "joseshowh@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0002-9186-6322")),
    person("Kah Seng", "Lian", , "kahseng@u.nus.edu", role = "aut"),
    person("Ana Rosa", "Castillo", , "arosacastillo@protonmail.com", role = "aut"),
    person("Zhuoyu", "Wang", , "wzhuoyu21@u.nus.edu", role = "aut"),
    person("Jun Yang", "Liao", , "name@example.com", role = "aut"),
    person("Felicia", "Low", , "lowminhuifelicia@gmail.com", role = "aut"),
    person("Tayfun", "Tumkaya", , role = "aut",
           comment = c(ORCID = "0000-0001-8425-3360")),
    person("Jonathan", "Anns", , role = "ctb",
           comment = c(ORCID = "0009-0005-8349-4986")),
    person("Yishan", "Mai", ,"maiyishan@u.duke.nus.edu", role = c("cre", "ctb"), 
           comment = c(ORCID = "0000-0002-7199-380X")),
    person("Sangyu", "Xu", , role = "ctb",
           comment = c(ORCID = "0000-0002-4927-9204")),
    person("Zinan", "Lu", , "zinan.lu@nus.edu.sg", role = "ctb"),
    person("Hyungwon", "Choi", , role = "ctb",
           comment = c(ORCID = "0000-0002-6687-3088")),
    person("Adam", "Claridge-Chang", , role = "ctb",
           comment = c(ORCID = "0000-0002-4583-3650")),
    person("ACCLAB", , role = c("cph", "fnd"))
  )
Description: Data Analysis using Bootstrap-Coupled ESTimation.  Estimation
    statistics is a simple framework that avoids the pitfalls of
    significance testing. It uses familiar statistical concepts: means,
    mean differences, and error bars. More importantly, it focuses on the
    effect size of one's experiment/intervention, as opposed to a false
    dichotomy engendered by P values.  An estimation plot has two key
    features: 1. It presents all datapoints as a swarmplot, which orders
    each point to display the underlying distribution.  2. It presents the
    effect size as a bootstrap 95% confidence interval on a separate but
    aligned axes.  Estimation plots are introduced in Ho et al., Nature
    Methods 2019, 1548-7105.  <doi:10.1038/s41592-019-0470-3>.  The
    free-to-view PDF is located at
    <https://www.nature.com/articles/s41592-019-0470-3.epdf?author_access_token=Euy6APITxsYA3huBKOFBvNRgN0jAjWel9jnR3ZoTv0Pr6zJiJ3AA5aH4989gOJS_dajtNr1Wt17D0fh-t4GFcvqwMYN03qb8C33na_UrCUcGrt-Z0J9aPL6TPSbOxIC-pbHWKUDo2XsUOr3hQmlRew%3D%3D>.
License: Apache License (>= 2)
URL: https://github.com/ACCLAB/dabestr,
        https://acclab.github.io/dabestr/
Depends: R (>= 2.10)
Imports: boot, brunnermunzel, cli, cowplot, dplyr, effsize, ggbeeswarm,
        ggplot2 (>= 3.5.2), ggsci, grid, magrittr, RColorBrewer, rlang,
        scales, stats, stringr, tibble, tidyr, viridisLite
Suggests: kableExtra, knitr, rmarkdown, testthat (>= 3.0.0), vdiffr
VignetteBuilder: kableExtra, knitr
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2025-10-28 03:47:42 UTC; jacobluke
Author: Joses W. Ho [aut] (ORCID: <https://orcid.org/0000-0002-9186-6322>),
  Kah Seng Lian [aut],
  Ana Rosa Castillo [aut],
  Zhuoyu Wang [aut],
  Jun Yang Liao [aut],
  Felicia Low [aut],
  Tayfun Tumkaya [aut] (ORCID: <https://orcid.org/0000-0001-8425-3360>),
  Jonathan Anns [ctb] (ORCID: <https://orcid.org/0009-0005-8349-4986>),
  Yishan Mai [cre, ctb] (ORCID: <https://orcid.org/0000-0002-7199-380X>),
  Sangyu Xu [ctb] (ORCID: <https://orcid.org/0000-0002-4927-9204>),
  Zinan Lu [ctb],
  Hyungwon Choi [ctb] (ORCID: <https://orcid.org/0000-0002-6687-3088>),
  Adam Claridge-Chang [ctb] (ORCID:
    <https://orcid.org/0000-0002-4583-3650>),
  ACCLAB [cph, fnd]
License_is_FOSS: yes
Repository: CRAN
Date/Publication: 2025-10-30 08:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 17:28:32 UTC; unix
