# Generated by roxygen2: do not edit by hand

S3method(print,dabest)
S3method(print,dabest_effectsize)
export("%>%")
export(cliffs_delta)
export(cohens_d)
export(cohens_h)
export(dabest_plot)
export(hedges_g)
export(load)
export(mean_diff)
export(median_diff)
importFrom(ggplot2,.pt)
importFrom(magrittr,"%>%")
